#
# spec file for package python-dns-lexicon
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dns-lexicon
Version:        3.21.1
Release:        1.1
Summary:        DNS record manipulation utility
License:        MIT
URL:            https://github.com/AnalogJ/lexicon
Source:         https://github.com/dns-lexicon/dns-lexicon/archive/refs/tags/v%{version}.tar.gz#/dns-lexicon-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION Python build system requirements
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1}
# /SECTION
# SECTION poetry.dependencies
BuildRequires:  %{python_module PyYAML >= 3}
BuildRequires:  %{python_module beautifulsoup4 >= 4}
BuildRequires:  %{python_module cryptography >= 3}
BuildRequires:  %{python_module pyotp}
BuildRequires:  %{python_module requests >= 2}
BuildRequires:  %{python_module tldextract >= 2}
# /SECTION
# SECTION extras
BuildRequires:  %{python_module boto3 >= 1.28}
BuildRequires:  %{python_module dnspython >= 2}
BuildRequires:  %{python_module localzone >= 0.9.8}
BuildRequires:  %{python_module softlayer => 5}
BuildRequires:  %{python_module softlayer-zeep >= 3}
# see comment in section testing below
# BuildRequires:  %%{python_module oci >= 2}
# /SECTION
# SECTION test dependencies
BuildRequires:  %{python_module pytest >= 3.8.0}
BuildRequires:  %{python_module vcrpy >= 1.13.0}
# OCI hijacks all connections during unit testing and lets them fail, we can't allow that on OBS
BuildConflicts: %{python_module oci}
# /SECTION
Requires:       python-PyYAML >= 3
Requires:       python-beautifulsoup4 >= 4
Requires:       python-cryptography >= 2
Requires:       python-dnspython >= 2
Requires:       python-pyotp
Requires:       python-requests >= 2
Requires:       python-tldextract >= 2
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-boto3 >= 1.28
Recommends:     python-localzone >= 0.9.8
Recommends:     python-oci >= 2
Recommends:     python-softlayer >= 5
Recommends:     python-softlayer-zeep >= 3
# Completely different pkg but same namespace
Conflicts:      python-lexicon
BuildArch:      noarch
%python_subpackages

%description
Lexicon provides a way to manipulate DNS records on multiple DNS providers
in a standardized way. Lexicon has a CLI, but it can also be used as a
Python library.

Lexicon was designed to be used in automation, specifically letsencrypt.

%prep
%autosetup -p1 -n dns-lexicon-%{version}
# rpmlint
find . -type f -name ".gitignore" -delete

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/lexicon
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_auto does not work inside OBS
ignoretests="--ignore tests/providers/test_auto.py"
# no oci in test suite, see comment above
ignoretests="$ignoretests --ignore tests/providers/test_oci.py"
# test_namecheap has invalid vcr casettes, attempts to update them failed
ignoretests="$ignoretests --ignore tests/providers/test_namecheap.py"
ignoretests="$ignoretests --ignore tests/providers/test_godaddy.py"
%pytest tests $ignoretests -x

%post
%python_install_alternative lexicon

%postun
%python_uninstall_alternative lexicon

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/lexicon
%{python_sitelib}/lexicon
%{python_sitelib}/dns_lexicon-%{version}*-info

%changelog
* Mon May 19 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.21.1
  * Make provider `dynu` able to work not only with the root domain of a zone (#31)
  * Remove the usage of a deprecated function of beautifulsoup (#29)
- from version 3.21.0
  * Add `devnomads` provider (#19)
  * Add `scaleway` provider (#21)
  * In `ionos` provider, authentication is not required
    when using automatic detection of registrar (#22)
  * In `hover` provider, prevent to send empty bodies in requests
    that would be refused by the API (#26)
  * Remove `webgo` provider (#20)
* Wed Jan  8 2025 Yunus Acar <yunus.acar@suse.com>
- update to 3.20.1:
  * Setup Docker entrypoint to run Lexicon by default
- update to 3.20.0:
  * Fix Docker build & migrate image to Github Container registry
- update to 3.19.0:
  * Add regfish provider (#2102)
  * Add ionos provider (#2127)
  * Add support of Python 3.13
  * Migrate build tooling from poetry to uv
  * Provider porkbun now use the new API exposed by the DNS provider (#2069)
  * Drop support of Python 3.8
- update to 3.18.0:
  * Add timeweb provider (#1850)
  * Add qcloud provider (#1824)
  * Update cloudflare documentation regarding the zoneID (#1783)
  * Add support of personal access tokens (PATs) in gandi provider (#1987)
  * Prevent invalid TTL values and proper behavior with subdomains in godaddy provider (#1834)
* Thu Dec 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- dnspython is not an optional requirement, bump it to Requires.
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.17.0:
  * New method to determine the actual zone name for a given
    FQDN. Historically it was an extraction
    of the second-level domain given well-known TLDs (eg.,
    `domain.net` for `www.domain.net`) using
    `tldextract`, and usage of `--delegated` option to enforce a
    specific zone name that is useful for
    third-level domains hosted on a specific zone (eg., sub-zone
    `sub.domain.net` delegated from zone
    `domain.net`).
  * It is now possible to use the `--resolve-zone-name` flag on
    Lexicon client to trigger an actual
    resolution of the zone name from a given FQDN using live DNS
    servers by leveraging `dnspython`
    utilities. Most of the time this makes `--delegated` useless,
    since Lexicon will be able to guess the correct zone name.
  * Add support to Python 3.12.
  * Support older versions of requests (<2.27.0) in `ovh`
    provider.
  * Drop support for Python 3.7
  * Protect `ovh` provider against invalid response bodies
  * that are returned sometimes by OVH APIs.
  * Fix filtering by record content in `godaddy` provider.
  * Add `pyotp` Python dependency in Lexicon to help implementing
    OTP (one-time password) on providers whose API supports this
    kind of authentication.
  * Add OTP support on `hover` provider, with a new flag named
    `--auth-totp-secret`.
  * Add type marker `py.typed` to inform types checkers about
    availability of type annotations in Lexicon codebase.
  * Stop using `cryptography` in providers where only hashing is
    needed.
* Mon Jul 31 2023 Dirk Müller <dmueller@suse.com>
- update to 3.12.0:
  * Add `duckdns` provider (experimental support) (#1533)
  * Add `dnsservices` provider (#1603)
  * Add `flexibleengine` provider (#1600)
  * Official support for Python 3.11
  * Upgrade API version used for `azure` provider (#1606)
  * Various fixes for documentation (#1488 #1458 #1601 #1605)
  * Fix check for extra dependencies (#1568)
* Sat Jul  1 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun May 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.11.7
  * Fix easyname provider (update action) (#1442)
- Release 3.11.6
  * Fix hetzner provider with large list of entries (#1389)
- Release 3.11.5
  * Fix upsertRecordSet in yandex provider (#1423)
- Release 3.11.4
  * Better management of domain zone id in yandex provider (#1338)
  * Fix create record action on glesys provider (#1356)
  * Fix create multiple TXT records for the same name in azure
    provider (#1359)
- Release 3.11.3
  * Add porkbun provider (#1283)
- Release 3.11.2
  * Add support of record update without an identifier in yandex
    provider (#1253)
- Release 3.11.1
  * Improve the Oracle Cloud DNS (oci) provider on the
    authentication mechanism (#1251)
  * Add API documentation to Oracle Cloud DNS (#1247)
- Release 3.11.0
  * Add namecom provider (#1212)
  * Fix TLD with two parts for namecheap provider (#1237)
  * Fix entity__name parsing in easyname provider (#1230)
- Release 3.10.0
  * Add --zone-id CLI flag for route53 provider
  * Add yandexcloud provider dedicated to Yandex Cloud solution
    (#1213)
  * Improve documentation with auto-generation
  * Clarify that yandex provider supports Yandex PDD only (#1211)
  * Use UUIDs in aliyun provider to avoid nonce collisions
- Release 3.9.5
  * Add misaka provider (#1205 #556)
  * Fix yandex provider for MX/SRV records (#1201)
  * Fix joker provider by using POST requests instead of GET
    (#1201)
- Update BuildRequirements: full poetry is not needed
* Mon Jul 11 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove BuildRequires/Recommends on zeep, due to softlayer-zeep.
* Wed Mar  9 2022 William Brown <william.brown@suse.com>
- Update to Version 3.9.4
  * Add webgo provider
  * Extend possible record types list for dreamhost provider
- Exclude test_oci.py due to failures.
- Remove skip on python36
- Drop remove-mock.patch, included upstream
* Wed Jul 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- No longer build for python 3.6: not all dependencies are
  available (e.g zeep).
* Thu Jan 28 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 3.5.3
  * Handle large number of hosted zones in route53 provider
- Changelog for 3.5.2
  * Fix domains in "lock" state with joker provider
- Changelog for 3.5.1
  * Add the Joker.com provider
  * Add environment variable TLDEXTRACT_CACHE_PATH to configure a
    tldextract cache custom location for Lexicon
  * Old environment variable TLDEXTRACT_CACHE_FILE is deprecated
    and will be removed in a future release
- Changelog for 3.5.0
  * Avoid installation problems with setuptools==50
  * Migrating codebase to Python 3.6+ specific features (Lexicon
    will explicitly break on older versions now)
  * Fix Easyname provider to work with their new website
- Changelog for 3.4.5
  * Add pagination support to Google Cloud DNS provider (#577)
  * Add official support to Python 3.9
  * Add SSHFP record support to CloudFlare provider (library only)
    (#612)
- Changelog for 3.4.4
  * Fix Gandi provider to use the new LiveDNS API URL
- Changelog for 3.4.3
  * Improve versions constraints by declaring latest major versions
    known to work with Lexicon
- Changelog for 3.4.2
  * Relax versions constraints on Lexicon dependencies until there
    is a real need.
- Changelog for 3.4.1
  * Add the Njalla provider
- Changelog for 3.4.0
  * Use poetry to manage dependencies, build and package Lexicon.
  * The beautifulsoup4 dependency has been integrated to the core
    ones for generic purpose. As a consequence henet, easyname and
    gratisdns providers do not have optional dependencies anymore.
  * Remove support for Python 2.7.
  * Remove support for Python 3.5.
  * Remove the extra security from requests dependency which does
    not make sense anymore on recent versions of Python.
- Changelog for 3.3.28
  * Fix localzone provider to make it work with dnspython 2.x.
  * Update easyname provider against the recent API changes.
* Wed Jul  8 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.3.26:
  * More straightforward approach to configure tests suites
  * Allow updating gandi RRSet TTL
  * Final customizations for hetzner dns api v1. The main fix is, that hetzner
    does not need the fqdn as record name
  * Add initial support for UltraDNS provider
  * Add support for record sets in Route53
  * Give a flag to set explicitly the zone ID and avoid unscoped API tokens
  * Test lowest and highest supported python versions. Move mostly to 3.x
  * Register properly the pytest mark ext_suite_1
  * Use Bearer Token Authorization for Cloudflare API Tokens
  * Remove Hetzner KonsoleH provider that is broken and not maintained
  * Implement pagination for cloudflare
- add remove-mock.patch gh#AnalogJ/lexicon#706
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar 30 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.3.19:
  * Implement retry to handle rate limits in DNSMadeEasy (#442)
  * Updated Link For Constellix API and Added Link for v2 of DNSSimple API
  * Bug fixed: failure if "Forward" Record (#447)
  * add RcodeZero (https://www.rcodezero.at) provider
  * Move test_hostingde provider in the correct place
  * Added example for lexicon usage as a python library
  * Add support for Python 3.8
  * minor fixes for RcodeZero provider: add "Accept" header to request and
    fixed loglevel of debug message
  * Change uri check after login for easyname
  * Fix auto provider handling of parameters. (#473)
  * Adds subaction as query parameter instead of using url argument
  * Introduce Gransy provider. Gransy provider is former Subreg provider, but
    because it works for multiple sites
  * Changes to robst parser 'html5lib' for Hetzner
  * Adds TTL to the digitalocean provider (#482)
- Drop Python 2 support, due to softlayer no longer supporting it
- Delete one broken unit test class
* Thu Oct 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in zeep dependency as zeep is borked and on the
  way from TW (subreg plugin no longer available)
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.3:
  * Failsafe list of records when some content is missing
  * Update provider specific dependencies link
  * Add DirectAdmin Provider (#418) * Add provider skeleton for DirectAdmin
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 3.3.1
  * Added provider logic & test recordings. Integration tests passed.
  * Added myself to codeowners file
  * Fixed the lint. Removed rtype filter in _update & _delete methods. Added _identifier helper
  * Update integration test recordings. Add provider to readme | iperurena
* Wed May 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.6:
  * Varous pylint fixes
* Fri Apr 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not use pytest macro for now to get this quickly to 15.1
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * Fix resolution of dependencies in a regular install of lexicon distribution
  * Mark more tests as expected failures
  * Fix the the updates of Gandi records of a specific type (#384)
  * Fix the if-condition that handles the updates of Gandi records of a specific rtype
- Drop merged patch:
  * ioerror.patch
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.6:
  * Various changes, no upstream changelog
- Add patch to fix network detection:
  * ioerror.patch
- Drop merged patch:
  * multiple-fixes-to-test_hetzner.patch
* Wed Jan 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop pytest reqs that are not really needed to reduce dependency
  pull
* Sat Dec 29 2018 Matej Cepl <mcepl@suse.com>
- Remove fix_regexps.patch and replace it with
  multiple-fixes-to-test_hetzner.patch, which fixes the same rpmlint
  issue and fixes test-hetzner above (gh#AnalogJ/lexicon#333)
* Mon Dec 24 2018 mcepl@suse.com
- Requires localzone -> python-localzone
* Wed Dec 19 2018 Matej Cepl <mcepl@suse.com>
- Update to version 3.0.7
- Fix tests (the only excluded tests are test_hetzner because of
  gh#AnalogJ/lexicon#333)
- Add fix_regexps.patch to fix gh#AnalogJ/lexicon#332
* Tue Nov 20 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.0.2
- Update BuildRequries and Requires from setup.py
  and test-requirements.txt
- Re-enable tests/providers/test_namecheap.py as the necessary
  namecheap libraries have been packaged now
- Disable tests/providers/test_localzone.py as this test
  requires an internet connection
* Mon Apr 23 2018 tchvatal@suse.com
- Conflict with python-lexicon that uses same namespace in sitedir
* Mon Apr 16 2018 jengelh@inai.de
- Use POSIX-compliant syntax of find (requires a directory).
  Use -delete in the same go.
- Update descriptions.
* Sun Apr 15 2018 tchvatal@suse.com
- Expand dependencies in order to run tests
* Sat Apr 14 2018 ecsos@opensuse.org
- Update to version 2.2.1
  No changelog from upstream.
* Wed Dec 13 2017 archie.cobbs@gmail.com
- Update to version 2.1.16
* Sun Jul 31 2016 archie.cobbs@gmail.com
- Update to version 1.1.9
  + Add support for setting TTL, with default 60 minutes
  + Add Gandi support
  + Added luadns support
  + Added fdqn method
  + Added certbot plugin
- Add missing requirement for python-setuptools
* Sun Jun 19 2016 archie.cobbs@gmail.com
- Initial creation of package, version 1.1.6
